Create an object of SensMLP class
SensMLP(
sens = list(),
raw_sens = list(),
mlp_struct = numeric(),
trData = data.frame(),
coefnames = character(),
output_name = character(),
cv = NULL,
boot = NULL,
boot.alpha = NULL
)SensMLP object
list of sensitivity measures, one data.frame per output neuron
list of sensitivities, one matrix per output neuron
numeric vector describing the structur of the MLP model
data.frame with the data used to calculate the sensitivities
character vector with the name of the predictor(s)
character vector with the name of the output(s)
list list with critical values of significance for std and mean square.
array bootstrapped sensitivity measures.
array significance level.
Defaults to NULL. Only available for analyzed caret::train models.
Pizarroso J, Portela J, Muñoz A (2022). NeuralSens: Sensitivity Analysis of Neural Networks. Journal of Statistical Software, 102(7), 1-36.